<?php

namespace WPDesk\GatewayWPPay\WooCommerceGateway;


class SubscriptionGateway extends \WC_Payment_Gateway {
	const ID = 'wppay-subscription';

	/** @var StandardPaymentGateway */
	private $gateway;

	public function __construct(StandardPaymentGateway $gateway) {
		$this->gateway = $gateway;

		$this->id                 = self::ID;
		$this->icon               = null;
		$this->has_fields         = false;
		$this->method_title       = __( 'WP Pay - subskrypcja', 'woocommerce-gateway-wp-pay' );
		$this->method_description = __( 'Lorem ipsum 3', 'woocommerce-gateway-wp-pay' );

		$this->init_form_fields();
		$this->init_settings();

		$this->enabled     = $this->gateway->get_option( 'enabled' );
		$this->description = $this->get_option( 'description', 'Lorem ipsum 4' );

		$this->title = $this->get_option( 'title', __( 'WP Pay - subskrypcja', 'woocommerce-gateway-wp-pay' ) );

		$this->supports = [
			'products',
			'refunds',
			'subscriptions',
			'subscription_cancellation',
			'subscription_suspension',
			'subscription_reactivation',
			'subscription_amount_changes',
			'subscription_date_changes',
			'subscription_payment_method_change',
			'subscription_payment_method_change_customer',
			'subscription_payment_method_change_admin',
			'multiple_subscriptions',
		];
	}

	public function hooks(): void {
		// add_filter( 'wcs_is_scheduled_payment_attempt', function(){
		//     return true;
		// });
		add_action( 'woocommerce_scheduled_subscription_payment_' . $this->id,
			[ $this, 'scheduled_subscription_payment' ], 10, 2 );
		add_action( 'woocommerce_subscription_failing_payment_method_updated_' . $this->id,
			[ $this, 'update_failing_payment_method' ], 10, 2 );
		// display the credit card used for a subscription in the "My Subscriptions" table
		add_filter( 'woocommerce_my_subscriptions_payment_method',
			[ $this, 'maybe_render_subscription_payment_method' ], 10, 2 );

		add_filter( 'woocommerce_payment_gateways', function ( $methods ) {
			$methods[] = $this;

			return $methods;
		} );
	}

	/**
	 * scheduled_subscription_payment function.
	 *
	 * @param $amount_to_charge float The amount to charge.
	 * @param $renewal_order    \WC_Order A WC_Order object created to record the renewal payment.
	 */
	public function scheduled_subscription_payment( $amount_to_charge, $renewal_order ) {
		try {
			$this->process_subscription_payment( $renewal_order, $amount_to_charge );
			//$renewal_order->payment_complete();
		} catch ( \Exception $e ) {
			$this->process_failed_payment( $renewal_order,
				sprintf( __( 'Transakcja PayU zakończyła się niepowodzeniem (%s)', 'woocommerce_payu' ),
					$e->getMessage() ) );
			//$this->notify_wcs_about_failed_payment( $renewal_order );
			$renewal_order->save();
		}

	}

	/**
	 * Update data to complete a payment to make up for
	 * an automatic renewal payment which previously failed.
	 *
	 * @access public
	 *
	 * @param \WC_Subscription $subscription  The subscription for which the failing payment method relates.
	 * @param \WC_Order        $renewal_order The order which recorded the successful payment (to make up for the failed automatic payment).
	 *
	 * @return void
	 */
	public function update_failing_payment_method( $subscription, $renewal_order ) {
		$payu_card_data = wpdesk_get_order_meta( $renewal_order, '_wppay_card_data', true );
		$payu_order     = wpdesk_get_order_meta( $renewal_order, '_wppay_order', true );
		$subscription->update_meta_data( '_wppay_card_data', $payu_card_data );
		$subscription->update_meta_data( '_wppay_order', $payu_order );
	}

	public function maybe_render_subscription_payment_method( $payment_method_to_display, $subscription ) {
		// bail for other payment methods
		if ( $this->id !== $subscription->get_payment_method() ) {
			return $payment_method_to_display;
		}

		$payu_card_data = wpdesk_get_order_meta( $subscription, '_wppay_card_data', true );
		if ( is_array( $payu_card_data ) && isset( $payu_card_data['masked_card'] ) ) {
			$payment_method_to_display = sprintf(
				__( 'PayU, karta: %s', 'woocommercee_payu' ),
				$payu_card_data['masked_card']
			);
		}

		return $payment_method_to_display;
	}


	/**
	 *
	 * @param \WC_Order $order
	 * @param string    $message
	 *
	 * @return void
	 */
	private function process_failed_payment( \WC_Order $order, $message = '', $status = 'failed' ) {
		if ( ! $this->is_failed ) {
			empty( $message ) ? $order->update_status( $status ) : $order->update_status( $status, $message );
			$this->is_failed = true;
		}
	}
}