<?php

declare (strict_types=1);
namespace WPPayVendor\JMS\Serializer\Builder;

use WPPayVendor\Doctrine\Common\Annotations\Reader;
use WPPayVendor\JMS\Serializer\Expression\CompilableExpressionEvaluatorInterface;
use WPPayVendor\JMS\Serializer\Metadata\Driver\AnnotationDriver;
use WPPayVendor\JMS\Serializer\Metadata\Driver\AttributeDriver;
use WPPayVendor\JMS\Serializer\Metadata\Driver\DefaultValuePropertyDriver;
use WPPayVendor\JMS\Serializer\Metadata\Driver\EnumPropertiesDriver;
use WPPayVendor\JMS\Serializer\Metadata\Driver\TypedPropertiesDriver;
use WPPayVendor\JMS\Serializer\Metadata\Driver\XmlDriver;
use WPPayVendor\JMS\Serializer\Metadata\Driver\YamlDriver;
use WPPayVendor\JMS\Serializer\Naming\PropertyNamingStrategyInterface;
use WPPayVendor\JMS\Serializer\Type\Parser;
use WPPayVendor\JMS\Serializer\Type\ParserInterface;
use WPPayVendor\Metadata\Driver\DriverChain;
use WPPayVendor\Metadata\Driver\DriverInterface;
use WPPayVendor\Metadata\Driver\FileLocator;
final class DefaultDriverFactory implements \WPPayVendor\JMS\Serializer\Builder\DriverFactoryInterface
{
    /**
     * @var ParserInterface
     */
    private $typeParser;
    /**
     * @var bool
     */
    private $enableEnumSupport = \false;
    /**
     * @var PropertyNamingStrategyInterface
     */
    private $propertyNamingStrategy;
    /**
     * @var CompilableExpressionEvaluatorInterface
     */
    private $expressionEvaluator;
    public function __construct(\WPPayVendor\JMS\Serializer\Naming\PropertyNamingStrategyInterface $propertyNamingStrategy, ?\WPPayVendor\JMS\Serializer\Type\ParserInterface $typeParser = null, ?\WPPayVendor\JMS\Serializer\Expression\CompilableExpressionEvaluatorInterface $expressionEvaluator = null)
    {
        $this->typeParser = $typeParser ?: new \WPPayVendor\JMS\Serializer\Type\Parser();
        $this->propertyNamingStrategy = $propertyNamingStrategy;
        $this->expressionEvaluator = $expressionEvaluator;
    }
    public function enableEnumSupport(bool $enableEnumSupport = \true) : void
    {
        $this->enableEnumSupport = $enableEnumSupport;
    }
    public function createDriver(array $metadataDirs, \WPPayVendor\Doctrine\Common\Annotations\Reader $annotationReader) : \WPPayVendor\Metadata\Driver\DriverInterface
    {
        if (\PHP_VERSION_ID >= 80000) {
            $annotationReader = new \WPPayVendor\JMS\Serializer\Metadata\Driver\AttributeDriver\AttributeReader($annotationReader);
        }
        $driver = new \WPPayVendor\JMS\Serializer\Metadata\Driver\AnnotationDriver($annotationReader, $this->propertyNamingStrategy, $this->typeParser);
        if (!empty($metadataDirs)) {
            $fileLocator = new \WPPayVendor\Metadata\Driver\FileLocator($metadataDirs);
            $driver = new \WPPayVendor\Metadata\Driver\DriverChain([new \WPPayVendor\JMS\Serializer\Metadata\Driver\YamlDriver($fileLocator, $this->propertyNamingStrategy, $this->typeParser, $this->expressionEvaluator), new \WPPayVendor\JMS\Serializer\Metadata\Driver\XmlDriver($fileLocator, $this->propertyNamingStrategy, $this->typeParser, $this->expressionEvaluator), $driver]);
        }
        if ($this->enableEnumSupport) {
            $driver = new \WPPayVendor\JMS\Serializer\Metadata\Driver\EnumPropertiesDriver($driver);
        }
        if (\PHP_VERSION_ID >= 70400) {
            $driver = new \WPPayVendor\JMS\Serializer\Metadata\Driver\TypedPropertiesDriver($driver, $this->typeParser);
        }
        if (\PHP_VERSION_ID >= 80000) {
            $driver = new \WPPayVendor\JMS\Serializer\Metadata\Driver\DefaultValuePropertyDriver($driver);
        }
        return $driver;
    }
}
